ml_kit
1.0.0
Module dataset
Module Items
Structs
Traits
In ml_
kit::
training
ml_kit
::
training
Module
dataset
Structs

DataSet
A dataset type, which for now is really just a queue of DataItems to output
Traits

Data
Item
A training sample that has a correct input and output